@@ -10,7 +10,7 @@ use Cwd;
 use English qw( -no_match_vars );
 use File::Basename;
 use File::Copy;
-use File::Path;
+use File::Path 2.08 qw/ make_path /;
 use File::Spec;
 use File::stat;
 use Params::Validate qw(:all);
@@ -124,8 +124,8 @@ PROMPT:
 
     chomp $response;
 
-    return $response if $response; # if they typed something, return it
-    return $default if $default;   # return the default, if available
+    return $response if defined $response; # if they typed something, return it
+    return $default if defined $default;   # return the default, if available
     return '';                     # return empty handed
 }
 
@@ -2304,7 +2304,7 @@ Provision::Unix::Utility - utility subroutines for sysadmin tasks
 
 =head1 VERSION
 
-version 1.03
+version 1.06
 
 =head1 SYNOPSIS
 
@@ -2977,7 +2977,7 @@ Matt Simerson <msimerson@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by The Network People, Inc..
+This software is copyright (c) 2013 by The Network People, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
