@@ -4,7 +4,7 @@ package Provision::Unix::Web::Apache;
 use strict;
 use warnings;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 use English qw( -no_match_vars );
 use Params::Validate qw( :all );
@@ -439,7 +439,7 @@ sub destroy {
 
     print "Dropping: \n" . join( "\n", @$drop ) . "\n";
 
-    if ( length @$new == 0 || length @$drop == 0 ) {
+    if ( scalar @$new == 0 || scalar @$drop == 0 ) {
         return {
             error_code => 500,
             error_desc => "yikes, something went horribly wrong!"
@@ -690,7 +690,7 @@ Provision::Unix::Web::Apache - provision web hosting accounts on Apache
 
 =head1 VERSION
 
-version 1.04
+version 1.06
 
 =head1 SYNOPSIS
 
@@ -811,7 +811,7 @@ Matt Simerson <msimerson@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by The Network People, Inc..
+This software is copyright (c) 2013 by The Network People, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
